@@ -61,31 +61,39 @@ d. epdTree can be improved in future based on real data statistics and more stru
 '''
 
 import sys
+import time
 from .workflow import *
 
 
 PARAMETERS = {
     'project_name': 'test_asari',
+    'outdir': 'asari_output_',
     
-    'min_intensity_threshold': 5000,    # minimal peak height
+    'min_intensity_threshold': 100,     # minimal intensity for mass track extraction, filtering baseline
+    'min_peak_height': 5000,            # minimal peak height
+    'cal_min_peak_height': 100000,      # minimal peak height required for peaks used for RT calibration
     'min_timepoints': 5,                # minimal number of data points in elution profile. scipy find_peaks treat `width` as FWHM, thus half of this value.
     'signal_noise_ratio': 2,            # peak height at least x fold over noise, which is median of non-peak data points.
     #
-    'peak_number_rt_calibration': 5,    # minimal number of selected high-quality peaks required for RT calibration. 
+    'peak_number_rt_calibration': 15,   # minimal number of selected high-quality peaks required for RT calibration. 
                                         # Samples with fewer selected peaks are dropped out.
+
+    # tweaking this section now -
     'cache_mass_traces': False,         # to save memory if not using DB; turn on if need to plot and diagnose
-    'output_filename': 'feature_table.tsv',
+    'output_feature_table': '_cmap_feature_table.csv',
+    'mass_grid_mapping': "_mass_grid_mapping.csv",
     'annotation_filename': "annotation_table.tsv",
+    'json_empricalCompounds': "_empCpd_json.json",
+
     #
     'mode': 'pos',                      # ionization mode
     'mass_range': (50, 2000),
-    'max_rtime': 300,                   # retention time range (chromatography) 0-300 seconds
+    #'max_rtime': 300,                   # retention time range (chromatography) 0-300 seconds
 
     'mz_tolerance': 5,                  # ppm, high selectivity meaning no overlap neighbors to confuse; 
                                         # Low selectivity regions will be still inspected to determine the true number of features
-
     'rtime_tolerance': 10,              # feature rtime shift threshold under 10 seconds; or 10% of rtime
-                                        # will change to automated parameter using stdev??
+                                        # not used now?
     #
     'initiation_samples': [],           # if user to specify 3 samples to initiate data processing, to init HOT_DB; 
                                         # otherwise they are chosen automatically
@@ -95,7 +103,7 @@ PARAMETERS = {
     'gaussian_shape': 0.3,              # min cutoff
     }
     
-PARAMETERS['min_prominence_threshold'] = PARAMETERS['min_intensity_threshold']/3.0
+PARAMETERS['min_prominence_threshold'] = PARAMETERS['min_peak_height']/3.0
 
 
 def read_project_dir(directory, file_pattern='.mzML'):
@@ -134,16 +142,17 @@ def process_project(list_input_files, dict_meta_data={}, parameters=PARAMETERS,
     EE.process_all()
 
 
-
-
-
-
-
-
 def main(directory):
+    time_stamp = str(time.time())
+    PARAMETERS['outdir'] += time_stamp
+    os.mkdir(PARAMETERS['outdir'])
+
     print("\n\n~~~~~~~ Hello from Asari! ~~~~~~~~~\n")
     process_project(
-            read_project_dir(directory), {}, PARAMETERS, directory   #setting output_dir as input dir
+            read_project_dir(directory), 
+            {},         # not used now
+            PARAMETERS, 
+            PARAMETERS['outdir']   #setting output_dir as input dir
     )
 
 #
