@@ -42,15 +42,14 @@ class ext_Experiment(Experiment):
         self.files_meta_data = dict_meta_data
         
         self.parameters = parameters
-        self.max_rtime = parameters['max_rtime'] # to update from each sample
-        # to update when samples are processed
-        self.number_scans = 0
+        # self.max_rtime = parameters['max_rtime'] # to update from each sample
+        self.number_scans = 0                                   # max scan number, to update when samples are processed
         self.mode = parameters['mode']
 
         self.initiation_samples = self.__choose_initiation_samples__(N=6)
 
         # SAMPLE_REGISTRY
-        self.allSamples = []                # list of Sample instances
+        self.all_samples = []               # list of Sample instances
         self.samples_nonreference = []
         self.samples_by_id = {}             # sample ID: Sample instance
         self.samples_by_name = {}           # input file name: Sample instance
@@ -73,18 +72,22 @@ class ext_Experiment(Experiment):
         # else:
         #      start DB after init
         
+        self.process_all_without_export()
+
+        # 
+        self.CMAP.MassGrid.to_csv(
+            os.path.join(self.parameters['outdir'], self.parameters['mass_grid_mapping']) )
+        self.annotate()
+        self.export_feature_table()
+
+
+    def process_all_without_export(self):
         self.CMAP = CompositeMap(self)
         self.CMAP.construct_mass_grid( self.process_initiation_samples() )
-        # 
-        self.CMAP.MassGrid.to_csv("__test_mass_grid.csv")
-        
         self.CMAP.align_retention_time()
         # some samples could fail alignment; can be processed and aligned at the end
         self.CMAP.global_peak_detection()
 
-        self.annotate()
-        self.export_feature_table()
-
 
     def process_initiation_samples(self):
         return [self.process_single_sample(f) for f in self.initiation_samples]
@@ -96,9 +99,12 @@ class ext_Experiment(Experiment):
 
         To add DB function HERE ??
         '''
+        mz_tolerance_ppm = self.parameters['mz_tolerance']
+        min_intensity = self.parameters['min_intensity_threshold']
+        min_timepoints = self.parameters['min_timepoints']
         try:
             SM = SimpleSample(self, self.mode, input_file)
-            SM.process()
+            SM.process( mz_tolerance_ppm, min_intensity, min_timepoints)
             # sample id, assigned by index in self.list_input_files.
             # DB commit
             return SM
@@ -121,24 +127,57 @@ class ext_Experiment(Experiment):
                 return random.sample(self.list_input_files, N)
 
 
-    def annotate(self, outfile='_empCpd_json.json'):
+    def annotate(self):
         '''Will add DB match too
         
         '''
+        outfile = os.path.join(self.parameters['outdir'], self.parameters['json_empricalCompounds'])
         ECCON = epdsConstructor(self.CMAP.FeatureList, mode=self.mode)
         list_empCpds = ECCON.peaks_to_epds()
+
+        list_empCpds = self._reformat_epds_(list_empCpds, self.CMAP.FeatureList)
         with open(outfile, 'w', encoding='utf-8') as f:
             json.dump(list_empCpds, f, ensure_ascii=False, indent=2)
 
         print("\nEmpirical compound annotaion (%d) was written to %s." %(len(list_empCpds), outfile))
 
 
+    def _reformat_epds_(self, list_empCpds, FeatureList):
+        fDict = {}
+        for F in FeatureList:
+            fDict[F['id_number']] = F
+        new = []
+        for E in list_empCpds:
+            features = []
+            for peak in E['list_peaks']:
+                features.append(
+                    {'feature_id': peak[0], 
+                    'mz': fDict[peak[0]]['mz'], 
+                    'rtime': fDict[peak[0]]['apex'], 
+                    'charged_formula': '', 
+                    'ion_relation': peak[1]}
+                )
+            new.append(
+                {
+                'interim_id': E['id'], 
+                'neutral_formula_mass': None,
+                'neutral_formula': None,
+                'Database_referred': [],
+                'identity': [],
+                'MS1_pseudo_Spectra': features,
+                'MS2_Spectra': [],
+                }
+            )
+        return new
+
+
     def export_feature_table(self, full=True, outfile='cmap_feature_table.csv'):
         '''
         Will need real RT time;
         Selectivity in m/z, RT and overall
         
         '''
+        outfile = os.path.join(self.parameters['outdir'], self.parameters['output_feature_table'])
         if full:
             self.CMAP.FeatureTable.to_csv(outfile)
         else:
